Skip to contents

Convert a tilePlan-inheriting object to a SpatVector of rectangle polygons, one per tile, with a tile attribute column holding the tile index. Padding is included in the polygon bounds.

Accelerated vectorized methods are provided for spatialTilePlan, freeTilePlan, and pointTilePlan. All other tilePlan subclasses fall back to extracting bounds via x[].

Usage

# S4 method for class 'tilePlan'
as.polygons(x, ...)

# S4 method for class 'freeTilePlan'
as.polygons(x, ...)

# S4 method for class 'pointTilePlan'
as.polygons(x, ...)

# S4 method for class 'spatialTilePlan'
as.polygons(x, ...)

Arguments

x

tilePlan-inheriting object

...

additional arguments (ignored)

Value

SpatVector of polygons

See also