Skip to contents

Get dimension characteristics of the tilePlan tiling plan. These produce information on how the tiles are arrayed in rows nrow(), cols ncol(), and total number of tiles length().

length<-() is a special case and currently only used with spatialTilePlan, where it is used to request a minimum number of tiles to generate.

Usage

# S4 method for class 'tilePlan'
nrow(x)

# S4 method for class 'tilePlan'
ncol(x)

# S4 method for class 'tilePlan'
length(x)

# S4 method for class 'tilePlan'
dim(x)

# S4 method for class 'spatialTilePlan'
length(x) <- value

# S4 method for class 'tileIterator'
length(x)

Arguments

x

tilePlan object

value

number of tiles to request

Value

numeric or spatialTilePlan object when using length<-()

Examples

x <- tilePlan()
ext(x) <- c(0, 100, 0, 100)
length(x)
#> [1] 0
length(x) <- 9
length(x)
#> [1] 9
dim(x)
#> [1] 3 3
nrow(x)
#> [1] 3
ncol(x)
#> [1] 3