Skip to contents

Virtual parent class for tile planning objects. These objects are for planning tiles/patches of data to be operated over. Objects are indexable across rows/columns of tiles and as a vector of tiles (similarly to a matrix).

[ indexing returns a set of bounds information for selection of the data. Tiles and bounds information are generated in a lazy fashion based on plan parameters, avoiding overhead with large amounts of tiles.

Slots

n

numeric. Number of tiles to create.

dims

numeric. Number of rows/cols in the array of tiles

tile_dims

numeric. Row/col dimensions of each tile

pad

numeric. Tile padding

metadata

data.frame. Metadata per tile

See also

spatialTilePlan and pixelTilePlan for concrete classes dealing with spatial and pixel-exact tiling respectively. tilePlan() for creation of these objects.

Other tile plans: freeTilePlan, freeTilePlan-class, pixelTilePlan-class, pointTilePlan-class, quadtreePlan(), spatialTilePlan-class, tilePlan, tilework-class