Get dimension characteristics of the tilePlan tiling plan. These
produce information on how the tiles are arrayed in rows nrow(), cols ncol(),
and total number of tiles length().
length<-() is a special case and currently only used with spatialTilePlan,
where it is used to request a minimum number of tiles to generate.
Usage
# S4 method for class 'tilePlan'
nrow(x)
# S4 method for class 'tilePlan'
ncol(x)
# S4 method for class 'tilePlan'
length(x)
# S4 method for class 'tilePlan'
dim(x)
# S4 method for class 'spatialTilePlan'
length(x) <- value
# S4 method for class 'tileIterator'
length(x)See also
Other tile* methods:
arith,
as.polygons(),
bracket,
centroids(),
dollar,
double_bracket,
ext(),
intersect(),
plot()