A stateful iterator that progresses through tiles of an underlying tilePlan
(or tileGroup if $active is set) object upon every call to $next_batch()
The closures that power this functionality are stored in @funs. The stateful
position handling is also internalized within.
See also
Other tile orchestration:
iterSplit(),
tileGroup,
tileGroup-class,
tileIterator